@@ -12,8 +12,9 @@ Options:
     -c, --checksum=[N]      YAML-file with checksums (on remote). [default: shelephant_checksum.yaml]
         --files-key=N       Path in the YAML-file, separated by "/". [default: /]
         --checksum-key=N    Path in the YAML-file, separated by "/". [default: /]
-    -i, --ignore            Skip basic checks.
-    -u, --update=[N]        Use host and prefix from existing file. [default: shelephant_hostinfo.yaml]
+        --ignore            Skip basic checks.
+    -i, --input=[N]         Use host and prefix from existing file. [default: shelephant_hostinfo.yaml]
+        --remove=N...       Remove paths (and checksums) from existing file.
         --force             Overwrite output file without prompt.
         --verbose           Verbose all commands.
     -h, --help              Show help.
@@ -26,6 +27,7 @@ import argparse
 import os
 import tempfile
 import shutil
+import numpy as np
 
 from .. import __version__
 from .. import YamlGetItem
@@ -34,6 +36,28 @@ from .. import YamlRead
 from .. import CopyFromRemote
 
 
+def remove(data, rm):
+
+    files = np.array(data['files'])
+    sorter = np.argsort(files)
+    files = files[sorter]
+    rm = np.sort(rm)
+
+    test = np.in1d(rm, files)
+    if not np.all(np.in1d(rm, files)):
+        raise IOError('One or more remove paths not found')
+
+    idx = np.searchsorted(files, rm)
+    keep = np.setdiff1d(np.arange(len(files)), sorter[idx])
+
+    files = data['files']
+    checksum = data['checksum']
+    data['files'] = [files[i] for i in keep]
+    data['checksum'] = [checksum[i] for i in keep]
+
+    return data
+
+
 def main():
 
     try:
@@ -52,10 +76,11 @@ def main():
         parser.add_argument('-p', '--prefix', required=False, default=None)
         parser.add_argument('-f', '--files', required=False, default=None, nargs='?', const='shelephant_dump.yaml')
         parser.add_argument('-c', '--checksum', required=False, default=None, nargs='?', const='shelephant_checksum.yaml')
-        parser.add_argument('-u', '--update', required=False, default=None, nargs='?', const='shelephant_hostinfo.yaml')
+        parser.add_argument('-i', '--input', required=False, default=None, nargs='?', const='shelephant_hostinfo.yaml')
         parser.add_argument(      '--files-key', required=False, default='/')
         parser.add_argument(      '--checksum-key', required=False, default='/')
-        parser.add_argument('-i', '--ignore', required=False, action='store_true')
+        parser.add_argument(      '--remove', required=False, nargs='*')
+        parser.add_argument(      '--ignore', required=False, action='store_true')
         parser.add_argument(      '--verbose', required=False, action='store_true')
         parser.add_argument('-v', '--version', action='version', version=__version__)
 
@@ -68,13 +93,25 @@ def main():
             '--prefix' : p.prefix,
             '--files' : p.files,
             '--checksum' : p.checksum,
-            '--update' : p.update,
+            '--input' : p.input,
             '--files-key' : p.files_key,
             '--checksum-key' : p.checksum_key,
+            '--remove' : p.remove,
             '--ignore' : p.ignore,
             '--verbose' : p.verbose,
         }
 
+        # Separate mode: remove paths and quit
+
+        if args['--remove']:
+            filename = args['--output']
+            if args['--input']:
+                filename = args['--input']
+            data = YamlRead(filename)
+            data = remove(data, args['--remove'])
+            YamlDump(args['--output'], data, args['--force'])
+            return 0
+
         # Extract basic information from command-line arguments
 
         data = {}
@@ -83,8 +120,8 @@ def main():
             if args['--' + item]:
                 data[item] = args['--' + item]
 
-        if args['--update']:
-            overwrite = YamlRead(args['--update'])
+        if args['--input']:
+            overwrite = YamlRead(args['--input'])
             for item in ['host', 'prefix']:
                 if item in overwrite:
                     data[item] = overwrite[item]
